
function waveform = OJR_sendshock(intensity)


%   CONFIGURE MACINE

% Clears any DAQ objects that are open (daqreset.m) and configures NI-DAQ
% with a single analogue output channel, range +/-10V, sample rate 1000Hz
% and two analogue input channels (14-15), range +/-10V, sample rate
% 1000Hz, logging to memory, 1s recording).
%
% Uses Eric's code from 13/7/10 (DS5.m) to hunt down the correct NI-DAQ 
% board (USB-6211) and configure that one specifically.
%

if (~isempty(daqfind));
    stop(daqfind)
end

daqreset;

ni = daqhwinfo('nidaq') ; % Results shown in commmand window
clear dev;
for n=1:length(ni.BoardNames);
    if strcmpi(ni.BoardNames{n},'USB-6218 (BNC)');
        dev = ni.InstalledBoardIds{n};  % Results shown in commmand window %commented to remove?
    end
end
if ~exist('dev','var') 
    error('USB-6218 not found')
end

global ao ai;

fprintf('Configuring data acquisition\n');
ai_fs    = 1000;  % trade-off storage against ability to capture DS5 output adquately
ao_fs    = 1000;  % adequate to deliver 10ms square waves, maybe not ideal if we use 1ms pulses

ao    = analogoutput('nidaq',dev);      % Analogue output object
chans = addchannel(ao,0);               % Output channel connected to DS5
set(ao.Channel,'OutputRange',[-10 10]); % Assuming 10V:10mA on DS5 this is a sensible default
set(ao.Channel,'UnitsRange',[-10 10]);  % Could cheekily change this to reflect DS5 settings but for cutaneous use, should never really need >10mA
set(ao,'SampleRate',ao_fs)

ai = analoginput('nidaq',dev);    % Analogue input object
set(ai,'InputType','SingleEnded') % Single-ended for our setup
chansi = addchannel(ai,[14 15])   % BNC inputs are plugged into AI 14/15
set(ai,'SampleRate',ai_fs)        % Set sample rate
ai.LogFileName='datalog';         % Default filename (will be overwritten - see below)
ai.LogToDiskMode = 'overwrite';   % Input data will be overwritten unless a new LogFileName is provided for each round of input
ai.LoggingMode = 'Disk';          % Write data to disk
ai.TriggerType = 'Immediate';     % Start analogue input on command "start(ai)"
ai.SamplesPerTrigger = ai_fs;     % 1s of data per trigger 

% 
%   waveform = JSW_give_single_shock(intensity);
%
% A function to allow me to change the nature of the shock delivered
% without changing multiple scripts / functions (e.g. JSW_PainMarkets.m,
% PainCurveFitting.m etc).
%
% Just update this code with the currently preferred stimulus waveform
% parameters, and it will do the rest...
%
% Current form: JSW_SquareWaveShock(10000,40000,intensity,5) 
%     i.e. 10ms on, 40ms off duty cycle with 5 repetitiions

if (nargin<1)
    intensity = 0.01;
end
waveform = JSW_SquareWaveShock(10000,40000,intensity,1);  % Takes ~250ms
